********
Glossary
********

.. glossary::

    Virtualenv
        A tool to create isolated Python environments.

        .. seealso:: https://virtualenv.pypa.io/en/latest/

    Markov Chain
        Stochastic model describing a sequence of possible events in which
        the probability of each event depends only on the state attained in the
        previous event.

        .. seealso:: https://en.wikipedia.org/wiki/Markov_chain
